@@ -10,29 +10,13 @@ fn main() {
         }
 
         let mut pool = 0;
+        let mut entropy = 0f64;
 
-        if core::has_digits(password) {
-            pool += 10;
-        }
-
-        if core::has_lowercase(password) {
-            pool += 26;
-        }
-
-        if core::has_uppercase(password) {
-            pool += 26;
-        }
-
-        if core::has_symbols(password) {
-            pool += 32;
-        }
-
-        let entropy = password.len() as f64 * (pool as f64).log2();
+        core::calculate_pool(&mut pool, password);
+        core::calculate_entropy(&mut entropy, &pool, password);
 
         println!("Entropy: {:.2} bits", entropy);
-        return;
-    }
-    {
+    } else {
         println!("No password provided.");
     }
 }
